@@ -12,7 +12,7 @@ class SiteAdmin(admin.ModelAdmin):
 
 try:
     admin.site.unregister(Site)
-except:
+except admin.sites.NotRegistered:
     pass
 admin.site.register(Site, SiteAdmin)
 
@@ -32,4 +32,9 @@ if defaults.SITE_ENABLE_SESSION_IN_ADMIN:
         exclude = ['session_data']
         date_hierarchy = 'expire_date'
 
+    try:
+        admin.site.unregister(Session)
+    except admin.sites.NotRegistered:
+        pass
+
     admin.site.register(Session, SessionAdmin)
